@@ -34,6 +34,7 @@ import cgi
 import datetime
 import errno
 from hashlib import sha1
+import json
 import logging
 import os
 import socket
@@ -47,7 +48,6 @@ if os.environ.get('USER_AGENT'):
 
 from boto import config
 import httplib2
-from oauth2client.anyjson import simplejson
 from oauth2client.client import AccessTokenRefreshError
 from oauth2client.client import HAS_CRYPTO
 from oauth2client.client import OAuth2Credentials
@@ -65,15 +65,15 @@ token_exchange_lock = threading.Lock()
 
 DEFAULT_SCOPE = 'https://www.googleapis.com/auth/devstorage.full_control'
 
-META_TOKEN_URI = ('http://metadata/computeMetadata/v1/instance/'
+METADATA_SERVER = 'http://metadata.google.internal'
+
+META_TOKEN_URI = (METADATA_SERVER + '/computeMetadata/v1/instance/'
                   'service-accounts/default/token')
 
 META_HEADERS = {
     'X-Google-Metadata-Request': 'True'
 }
 
-METADATA_SERVER = 'http://169.254.169.254'
-
 
 # Note: this is copied from gsutil's gslib.cred_types. It should be kept in
 # sync. Also note that this library does not use HMAC, but it's preserved from
@@ -533,7 +533,7 @@ class OAuth2GCEClient(OAuth2Client):
       raise GsAccessTokenRefreshError()
 
     if response.status == 200:
-      d = simplejson.loads(content)
+      d = json.loads(content)
 
       return AccessToken(
           d['access_token'],
@@ -629,4 +629,3 @@ class AccessToken(object):
 
   def __str__(self):
     return 'AccessToken(token=%s, expiry=%sZ)' % (self.token, self.expiry)
-
